==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/pt-BR/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Uma conta com este e-mail já existe.',
    'account_not_found'      => 'O nome do usuário ou a senha estão incorretos.',
    'account_not_activated'  => 'Esta conta de usuário não está ativada.',
    'account_suspended'      => 'Esta conta de usuário está suspensa.',
    'account_banned'         => 'Esta conta de usuário está banida.',
    'throttle'               => 'Muitas tentativas com falha de login. Por favor, tente novamente em :minutes minutos.',

    'two_factor' => array(
        'already_enrolled'      => 'Seu dispositivo já está inscrito.',
        'success'               => 'Você logou na sua conta com sucesso.',
        'code_required'         => 'O código de dois fatores é obrigatório.',
        'invalid_code'          => 'O código de dois fatores é inválido.',
    ),

    'signin' => array(
        'error'   => 'Houve um problema ao tentar-lhe entrar, tente novamente.',
        'success' => 'Você entrou com sucesso.',
    ),

    'logout' => array(
        'error'   => 'Houve um problema ao tentar desconectar, por favor, tente novamente.',
        'success' => 'Você se desconectou com sucesso.',
    ),

    'signup' => array(
        'error'   => 'Houve um problema ao tentar criar sua conta, tente novamente.',
        'success' => 'Conta criada com sucesso.',
    ),

    'forgot-password' => array(
        'error'   => 'Houve um problema ao tentar obter um código de redefinição da senha, tente novamente.',
        'success' => 'Se esse endereço de e-mail existir em nosso sistema, um e-mail de recuperação de senha foi enviado.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Houve um problema ao tentar redefinir sua senha, tente novamente.',
        'success' => 'Sua senha foi redefinida com sucesso.',
    ),


);

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/pt-BR/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Uma conta com este e-mail já existe.',
    'account_not_found'      => 'O nome do usuário ou a senha estão incorretos.',
    'account_not_activated'  => 'Esta conta de usuário não está ativada.',
    'account_suspended'      => 'Esta conta de usuário está suspensa.',
    'account_banned'         => 'Esta conta de usuário está banida.',
    'throttle'               => 'Muitas tentativas com falha de login. Por favor, tente novamente em :minutes minutos.',

    'two_factor' => array(
        'already_enrolled'      => 'Seu dispositivo já está inscrito.',
        'success'               => 'Você logou na sua conta com sucesso.',
        'code_required'         => 'O código de dois fatores é obrigatório.',
        'invalid_code'          => 'O código de dois fatores é inválido.',
        'enter_two_factor_code' => 'Please enter your two-factor authentication code.',
        'please_enroll'         => 'Please enroll a device in two-factor authentication.',
    ),

    'signin' => array(
        'error'   => 'Houve um problema ao tentar-lhe entrar, tente novamente.',
        'success' => 'Você entrou com sucesso.',
    ),

    'logout' => array(
        'error'   => 'Houve um problema ao tentar desconectar, por favor, tente novamente.',
        'success' => 'Você se desconectou com sucesso.',
    ),

    'signup' => array(
        'error'   => 'Houve um problema ao tentar criar sua conta, tente novamente.',
        'success' => 'Conta criada com sucesso.',
    ),

    'forgot-password' => array(
        'error'   => 'Houve um problema ao tentar obter um código de redefinição da senha, tente novamente.',
        'success' => 'Se esse endereço de e-mail existir em nosso sistema, um e-mail de recuperação de senha foi enviado.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Houve um problema ao tentar redefinir sua senha, tente novamente.',
        'success' => 'Sua senha foi redefinida com sucesso.',
    ),


);
